<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">



<!--[if lt IE 9]>
        <script src="3rdPcomponents/html5shiv/html5shiv.min.js"></script>
<![endif]-->



<meta http-equiv="refresh" content="0; url=/SSACCTT/page.php" />
<style>
 body {
                background:                     #1a1a1a;
                color:                          #fff;
                font-family:            helvetica, arial, sans-serif;
                font-size:                      62.5%;
                line-height:            2.1em;
                margin:                         0;
                padding:                        0;
        }
</style>
<body>
</body>
