<?php
$userphotoenable="yes";//yes to enable user photos anything else to disable
$usersgroup=""; //AD group that can use the recovery functions
$adminsgroup=""; //AD group that can use admin functions logs etc
$numberofsq="6"; //number of secret questions for the user to fill in
$minnumberofsq="6";  //minimum number of secret questions the user has to fill in to enable recovery
$sysemailadd=""; //address the system uses send emails to users
$cipherkey = ""; //cypher key for encoding Q's&A's keep this safe
?>
