<?php

$ldap_account_suffix="";
$ldap_base_dn="";
$ldap_domain_controllers="";
$ldap_admin_username="";
$ldap_admin_password="";
$ldap_real_primarygroup="";
$ldap_use_ssl="";
$ldap_use_tls="";
$ldap_recursive_groups="";
$ldap_ad_port="";
$ldap_sso="";

?>

