input:invalid{
border: 4px solid red;
}

a {
	text-decoration:none;
	color:#00c6ff;
}
.container {width: 960px; margin: 0 auto; overflow: hidden;}
#content {	float: left; width: 100%;}
.post { margin: 0 auto; padding-bottom: 50px; float: left; width: 960px; } 
.btn-sign {
	width:460px;
	margin-bottom:20px;
	margin:0 auto;
	padding:20px;
	border-radius:5px;
	background: -moz-linear-gradient(center top, #0000ff, #aaaaff);
    	background: -webkit-gradient(linear, left top, left bottom, from(#0000ff), to(#0000aa));
	background: -o-linear-gradient(top, #0000ff, #0000aa);
    	filter: progid:DXImageTransform.Microsoft.gradient(startColorStr='#0000ff', EndColorStr='#0000aa');
	text-align:center;
	font-size:36px;
	color:#fff;
	text-transform:uppercase;
}
.btn-sign:hover { background:#00a; } .btn-sign a { color:#fff; text-shadow:0 1px 2px #161616; }

#content-sq {      float: left; width: 100%;}
.post-sq { margin: 0 auto; padding-bottom: 50px; float: left; width: 60px; }
.btn-sign-sq {
	background: -moz-linear-gradient(center top, #f3f3f3, #aaaaaa);
        background: -webkit-gradient(linear, left top, left bottom, from(#f3f3f3), to(#aaaaaa));
        background: -o-linear-gradient(top, #f3f3f3, #aaaaaa);
        filter: progid:DXImageTransform.Microsoft.gradient(startColorStr='#f3f3f3', EndColorStr='#aaaaaa');
        border-color:#FFF;
        border-width:1px;
        border-radius:4px 4px 4px 4px;
        -moz-border-radius: 4px;
        -webkit-border-radius: 4px;
        color:#333;
        cursor:pointer;
        display:inline-block;
        padding:6px 6px 4px;
        margin-top:10px;
        font:12px;
        width:214px;
}
.btn-sign-sq:hover { background:#ddd; } a {
        text-decoration:none;
        color:#00c6ff;
}




#mask {
	display: none;
	background: #a00;
	position: fixed; left: 0; top: 0;
	z-index: 10;
	width: 100%; height: 100%;
	opacity: 0.6;
	z-index: 999;
}
.login-popup{
	display:none;
	background: #333;
	padding: 10px;
	border: 2px solid #ddd;
	float: left;
	font-size: 1.2em;
	position: fixed;
	top: 50%; left: 50%;
	z-index: 99999;
	box-shadow: 0px 0px 20px #999;
	-moz-box-shadow: 0px 0px 20px #999; /* Firefox */
    	-webkit-box-shadow: 0px 0px 20px #999; /* Safari, Chrome */
	border-radius:3px 3px 3px 3px;
    	-moz-border-radius: 3px; /* Firefox */
    	-webkit-border-radius: 3px; /* Safari, Chrome */
}
img.btn_close {
	float: right;
	margin: -28px -28px 0 0;
}
fieldset {
	border:none;
}
form.signin .textbox label {
	display:block;
	padding-bottom:7px;
}
form.signin .textbox span {
	display:block;
}
form.signin p, form.signin span {
	color:#999;
	font-size:11px;
	line-height:18px;
} 
form.signin .textbox input {
	background:#666666;
	border-bottom:1px solid #333;
	border-left:1px solid #000;
	border-right:1px solid #333;
	border-top:1px solid #000;
	color:#fff;
	border-radius: 3px 3px 3px 3px;
	-moz-border-radius: 3px;
    	-webkit-border-radius: 3px;
	font:13px Arial, Helvetica, sans-serif;
	padding:6px 6px 4px;
	width:200px;
}
form.signin input:-moz-placeholder { color:#bbb; text-shadow:0 0 2px #000; } form.signin input::-webkit-input-placeholder { color:#bbb; text-shadow:0 0 2px #000; } 
.button {
	background: -moz-linear-gradient(center top, #f3f3f3, #aaaaaa);
	background: -webkit-gradient(linear, left top, left bottom, from(#f3f3f3), to(#aaaaaa));
	background: -o-linear-gradient(top, #f3f3f3, #aaaaaa);
    	filter: progid:DXImageTransform.Microsoft.gradient(startColorStr='#f3f3f3', EndColorStr='#aaaaaa');
	border-color:#FFF;
	border-width:1px;
	border-radius:4px 4px 4px 4px;
	-moz-border-radius: 4px;
    	-webkit-border-radius: 4px;
	color:#333;
	cursor:pointer;
	display:inline-block;
	padding:6px 6px 4px;
	margin-top:10px;
	font:12px;
	width:214px;
}
.button:hover { background:#ddd; } a {
	text-decoration:none;
	color:#00c6ff;
}
.container {width: 960px; margin: 0 auto; overflow: hidden;}
#content {	float: left; width: 100%;}
.post { margin: 0 auto; padding-bottom: 50px; float: left; width: 960px; } .btn-sign {
	width:460px;
	margin-bottom:20px;
	margin:0 auto;
	padding:20px;
	border-radius:5px;
	background: -moz-linear-gradient(center top, #0000ff, #aaaaff);
    	background: -webkit-gradient(linear, left top, left bottom, from(#0000ff), to(#0000aa));
	background: -o-linear-gradient(top, #0000ff, #0000aa);
    	filter: progid:DXImageTransform.Microsoft.gradient(startColorStr='#0000ff', EndColorStr='#0000aa');
	text-align:center;
	font-size:36px;
	color:#fff;
	text-transform:uppercase;
}
.btn-sign:hover { background:#00a; } .btn-sign a { color:#fff; text-shadow:0 1px 2px #161616; }
#mask {
	display: none;
	background: #a00;
	position: fixed; left: 0; top: 0;
	z-index: 10;
	width: 100%; height: 100%;
	opacity: 0.6;
	/* Next 2 lines IE8 */
        -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)" !important;
	z-index: 999;
}
.login-popup{
	display:none;
	background: #333;
	padding: 10px;
	border: 2px solid #ddd;
	float: left;
	font-size: 1.2em;
	position: fixed;
	top: 50%; left: 50%;
	z-index: 99999;
	box-shadow: 0px 0px 20px #999;
	-moz-box-shadow: 0px 0px 20px #999; /* Firefox */
    	-webkit-box-shadow: 0px 0px 20px #999; /* Safari, Chrome */
	border-radius:3px 3px 3px 3px;
    	-moz-border-radius: 3px; /* Firefox */
    	-webkit-border-radius: 3px; /* Safari, Chrome */
}
img.btn_close {
	float: right;
	margin: -28px -28px 0 0;
}
fieldset {
	border:none;
}
lhf{
float: left;
}

rhf{
float: right;
}


form.signin .textbox label {
	display:block;
	padding-bottom:7px;
}
form.signin .textbox span {
	display:block;
}
form.signin p, form.signin span {
	color:#999;
	font-size:11px;
	line-height:18px;
} 
form.signin .textbox input {
	background:#666666;
	border-bottom:1px solid #333;
	border-left:1px solid #000;
	border-right:1px solid #333;
	border-top:1px solid #000;
	color:#fff;
	border-radius: 3px 3px 3px 3px;
	-moz-border-radius: 3px;
    	-webkit-border-radius: 3px;
	font:13px Arial, Helvetica, sans-serif;
	padding:6px 6px 4px;
	width:200px;
}
 .input:invalid{
  border: 4px solid red;
  background:#ff6666;
  }

form.signin input:-moz-placeholder { color:#bbb; text-shadow:0 0 2px #000; } form.signin input::-webkit-input-placeholder { color:#bbb; text-shadow:0 0 2px #000; }

 .button {
	background: -moz-linear-gradient(center top, #f3f3f3, #aaaaaa);
	background: -webkit-gradient(linear, left top, left bottom, from(#f3f3f3), to(#aaaaaa));
	background: -o-linear-gradient(top, #f3f3f3, #aaaaaa);
    	filter: progid:DXImageTransform.Microsoft.gradient(startColorStr='#f3f3f3', EndColorStr='#aaaaaa');
	border-color:#FFF;
	border-width:1px;
	border-radius:4px 4px 4px 4px;
	-moz-border-radius: 4px;
	-webkit-border-radius: 4px;
	color:#333;
	cursor:pointer;
	display:inline-block;
	padding:6px 6px 4px;
	margin-top:10px;
	font:12px;
	width:214px;
}
.button:hover { background:#ddd; }
