passwdcngform{
}

passwdcngform button{
background: -moz-linear-gradient(center top, #f3f3f3, #aaaaaa);
background: -webkit-gradient(linear, left top, left bottom, from(#f3f3f3), to(#aaaaaa));
background: -o-linear-gradient(top, #f3f3f3, #aaaaaa);
filter: progid:DXImageTransform.Microsoft.gradient(startColorStr='#f3f3f3', EndColorStr='#aaaaaa');
border-color: #FFF;
border-width: 1px;
border-radius: 4px 4px 4px 4px;
-moz-border-radius: 4px;
-webkit-border-radius: 4px;
color: #333;
cursor: pointer;
display: inline-block;
padding: 6px 6px 4px;
margin-top: 10px;
font: 12px;
width: 214px;
	}

