<?php
error_reporting(E_ALL);
ini_set('display_errors', '0');
$masterversion="Version 1.4.b.1";
$appbasepath="/var/www/WebAD-PwR";
$csspath="css/";
$loginlogopath="./images/logo3.png";
$loginlogosizeWidth="250px";
$userimgsizeWidth="80px";
?>
