body{
background-color:#d0e4fe;
font-family:"arial";
}
version{
font-family:"arial";
font-size:1.0em;
}
h2{
text-align:center;
}
h3{
text-align:center;
font-size:1.0em;
}
textcenter{
text-align:center;
}
